.. _add-gff-info:

add-gff-info - Add informations to GFF annotations
==================================================

Overview
--------

.. automodule:: mgkit.workflow.add_gff_info

Options
-------

.. click:: mgkit.workflow.add_gff_info:main
   :prog: add-gff-info
   :show-nested:
